<?php
require_once '../config.php';

if (!isset($_SESSION['admin_logged_in'])) {
    header('Location: login.php');
    exit;
}

// Başvuruları getir
$query = "SELECT a.*, s.school_name 
          FROM applications a 
          LEFT JOIN schools s ON a.school_id = s.id 
          WHERE a.is_verified = 1 
          ORDER BY a.created_at DESC";
$applications = $conn->query($query);
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Panel - TAKTİK ŞOV İZMİR</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.datatables.net/1.11.5/css/dataTables.bootstrap5.min.css" rel="stylesheet">
    <style>
        .navbar {
            background-color: #ff6b00 !important;
        }
        .btn-primary {
            background-color: #ff6b00;
            border-color: #ff6b00;
        }
        .btn-primary:hover {
            background-color: #e65d00;
            border-color: #e65d00;
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-dark navbar-expand-lg">
        <div class="container">
            <a class="navbar-brand" href="#">
                <img src="../assets/img/logo.png" alt="TAKTİK ŞOV İZMİR" height="40">
                TAKTİK ŞOV İZMİR - Admin Panel
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link active" href="index.php">Başvurular</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="manual_application.php">Manuel Başvuru</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="sms_templates.php">SMS Şablonları</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="logout.php">Çıkış</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <div class="container mt-4">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h2>Başvurular</h2>
            <div>
                <a href="export.php" class="btn btn-success">Excel'e Aktar</a>
            </div>
        </div>

        <div class="table-responsive">
            <table class="table table-striped" id="applicationsTable">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Ad Soyad</th>
                        <th>TC No</th>
                        <th>Telefon</th>
                        <th>Okul</th>
                        <th>Sınıf</th>
                        <th>Başvuru Tarihi</th>
                        <th>Tür</th>
                        <th>İşlemler</th>
                    </tr>
                </thead>
                <tbody>
                    <?php while ($row = $applications->fetch_assoc()): ?>
                    <tr>
                        <td><?php echo $row['id']; ?></td>
                        <td><?php echo htmlspecialchars($row['full_name']); ?></td>
                        <td><?php echo $row['tc_no']; ?></td>
                        <td><?php echo $row['phone']; ?></td>
                        <td><?php echo htmlspecialchars($row['school_name']); ?></td>
                        <td><?php echo $row['class_level']; ?></td>
                        <td><?php echo date('d.m.Y H:i', strtotime($row['created_at'])); ?></td>
                        <td><?php echo $row['is_manual'] ? 'Manuel' : 'Online'; ?></td>
                        <td>
                            <button class="btn btn-sm btn-primary edit-btn" data-id="<?php echo $row['id']; ?>">Düzenle</button>
                            <button class="btn btn-sm btn-danger delete-btn" data-id="<?php echo $row['id']; ?>">Sil</button>
                        </td>
                    </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- Düzenleme Modal -->
    <div class="modal fade" id="editModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Başvuru Düzenle</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <form id="editForm">
                        <input type="hidden" id="editId" name="id">
                        <div class="mb-3">
                            <label for="editFullName" class="form-label">Ad Soyad:</label>
                            <input type="text" class="form-control" id="editFullName" name="fullName" required>
                        </div>
                        <div class="mb-3">
                            <label for="editPhone" class="form-label">Telefon:</label>
                            <input type="tel" class="form-control" id="editPhone" name="phone" required>
                        </div>
                        <div class="mb-3">
                            <label for="editSchool" class="form-label">Okul:</label>
                            <select class="form-select" id="editSchool" name="school" required>
                                <?php 
                                $schools = $conn->query("SELECT * FROM schools ORDER BY school_name");
                                while ($school = $schools->fetch_assoc()):
                                ?>
                                <option value="<?php echo $school['id']; ?>">
                                    <?php echo htmlspecialchars($school['school_name']); ?>
                                </option>
                                <?php endwhile; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="editClass" class="form-label">Sınıf:</label>
                            <select class="form-select" id="editClass" name="classLevel" required>
                                <option value="9">9. Sınıf</option>
                                <option value="10">10. Sınıf</option>
                                <option value="11">11. Sınıf</option>
                                <option value="12">12. Sınıf</option>
                                <option value="Mezun">Mezun</option>
                                <option value="Ortaokul">Ortaokul</option>
                            </select>
                        </div>
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">İptal</button>
                    <button type="button" class="btn btn-primary" id="saveEdit">Kaydet</button>
                </div>
            </div>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.5/js/dataTables.bootstrap5.min.js"></script>
    <script>
        $(document).ready(function() {
            const table = $('#applicationsTable').DataTable({
                "language": {
                    "url": "//cdn.datatables.net/plug-ins/1.11.5/i18n/tr.json"
                }
            });
            
            // Düzenleme
            $('.edit-btn').click(function() {
                const id = $(this).data('id');
                $.get('get_application.php', {id: id}, function(data) {
                    const application = JSON.parse(data);
                    $('#editId').val(application.id);
                    $('#editFullName').val(application.full_name);
                    $('#editPhone').val(application.phone);
                    $('#editSchool').val(application.school_id);
                    $('#editClass').val(application.class_level);
                    $('#editModal').modal('show');
                });
            });
            
            // Kaydetme
            $('#saveEdit').click(function() {
                $.post('update_application.php', $('#editForm').serialize(), function(response) {
                    if (response.status === 'success') {
                        location.reload();
                    } else {
                        alert('Güncelleme başarısız!');
                    }
                });
            });
            
            // Silme
            $('.delete-btn').click(function() {
                if (confirm('Bu başvuruyu silmek istediğinizden emin misiniz?')) {
                    const id = $(this).data('id');
                    $.post('delete_application.php', {id: id}, function(response) {
                        if (response.status === 'success') {
                            location.reload();
                        } else {
                            alert('Silme işlemi başarısız!');
                        }
                    });
                }
            });
        });
    </script>
</body>
</html>
