<?php
require_once '../config.php';

if (!isset($_SESSION['admin_logged_in'])) {
    header('Location: login.php');
    exit;
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $fullName = cleanInput($_POST['fullName']);
    $tcNo = cleanInput($_POST['tcNo']);
    $phone = cleanInput($_POST['phone']);
    $school = (int)$_POST['school'];
    $classLevel = cleanInput($_POST['classLevel']);
    
    // TC ve telefon kontrolü
    $check = $conn->query("SELECT id FROM applications WHERE tc_no = '$tcNo' OR phone = '$phone'");
    if ($check->num_rows > 0) {
        $error = 'Bu TC veya telefon numarası ile daha önce başvuru yapılmış!';
    } else {
        // Manuel başvuru ekle
        $stmt = $conn->prepare("INSERT INTO applications (full_name, tc_no, phone, school_id, class_level, is_verified, is_manual) VALUES (?, ?, ?, ?, ?, 1, 1)");
        $stmt->bind_param("sssis", $fullName, $tcNo, $phone, $school, $classLevel);
        
        if ($stmt->execute()) {
            // SMS şablonunu al ve gönder
            $template_query = $conn->query("SELECT template_content FROM sms_templates WHERE template_name = 'success'");
            $template = $template_query->fetch_assoc()['template_content'];
            
            $message = str_replace('{AD_SOYAD}', $fullName, $template);
            sendSMS('0' . $phone, $message);
            
            $success = 'Başvuru başarıyla eklendi ve onay SMS\'i gönderildi.';
        } else {
            $error = 'Başvuru eklenirken bir hata oluştu!';
        }
    }
}

// Okulları getir
$schools = $conn->query("SELECT * FROM schools ORDER BY school_name");
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manuel Başvuru - TAKTİK ŞOV İZMİR</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .navbar {
            background-color: #ff6b00 !important;
        }
        .btn-primary {
            background-color: #ff6b00;
            border-color: #ff6b00;
        }
        .btn-primary:hover {
            background-color: #e65d00;
            border-color: #e65d00;
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-dark navbar-expand-lg">
        <div class="container">
            <a class="navbar-brand" href="#">TAKTİK ŞOV İZMİR - Admin Panel</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" href="index.php">Başvurular</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link active" href="manual_application.php">Manuel Başvuru</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="sms_templates.php">SMS Şablonları</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="logout.php">Çıkış</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <div class="container mt-4">
        <div class="row justify-content-center">
            <div class="col-md-8">
                <div class="card">
                    <div class="card-header">
                        <h4 class="mb-0">Manuel Başvuru Ekle</h4>
                    </div>
                    <div class="card-body">
                        <?php if (isset($success)): ?>
                            <div class="alert alert-success"><?php echo $success; ?></div>
                        <?php endif; ?>
                        
                        <?php if (isset($error)): ?>
                            <div class="alert alert-danger"><?php echo $error; ?></div>
                        <?php endif; ?>

                        <form method="POST">
                            <div class="mb-3">
                                <label for="fullName" class="form-label">Ad Soyad:</label>
                                <input type="text" class="form-control" id="fullName" name="fullName" required>
                            </div>
                            
                            <div class="mb-3">
                                <label for="tcNo" class="form-label">TC Kimlik No:</label>
                                <input type="text" class="form-control" id="tcNo" name="tcNo" required 
                                       pattern="[0-9]{11}" maxlength="11" minlength="11">
                            </div>
                            
                            <div class="mb-3">
                                <label for="phone" class="form-label">Cep Telefonu:</label>
                                <input type="tel" class="form-control" id="phone" name="phone" required 
                                       pattern="[0-9]{10}" maxlength="10" placeholder="5xxxxxxxxx">
                            </div>
                            
                            <div class="mb-3">
                                <label for="school" class="form-label">Okul:</label>
                                <select class="form-select" id="school" name="school" required>
                                    <option value="">Okul Seçiniz</option>
                                    <?php while ($school = $schools->fetch_assoc()): ?>
                                    <option value="<?php echo $school['id']; ?>">
                                        <?php echo htmlspecialchars($school['school_name']); ?>
                                    </option>
                                    <?php endwhile; ?>
                                </select>
                            </div>
                            
                            <div class="mb-3">
                                <label for="classLevel" class="form-label">Sınıf:</label>
                                <select class="form-select" id="classLevel" name="classLevel" required>
                                    <option value="">Sınıf Seçiniz</option>
                                    <option value="9">9. Sınıf</option>
                                    <option value="10">10. Sınıf</option>
                                    <option value="11">11. Sınıf</option>
                                    <option value="12">12. Sınıf</option>
                                    <option value="Mezun">Mezun</option>
                                    <option value="Ortaokul">Ortaokul</option>
                                </select>
                            </div>
                            
                            <button type="submit" class="btn btn-primary">Başvuru Ekle</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
