<?php
require_once '../config.php';

if (!isset($_SESSION['admin_logged_in'])) {
    header('Location: login.php');
    exit;
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $templateId = (int)$_POST['template_id'];
    $content = cleanInput($_POST['content']);
    
    $stmt = $conn->prepare("UPDATE sms_templates SET template_content = ? WHERE id = ?");
    $stmt->bind_param("si", $content, $templateId);
    
    if ($stmt->execute()) {
        $success = 'SMS şablonu başarıyla güncellendi.';
    } else {
        $error = 'SMS şablonu güncellenirken bir hata oluştu!';
    }
}

// SMS şablonlarını getir
$templates = $conn->query("SELECT * FROM sms_templates ORDER BY id");
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>SMS Şablonları - TAKTİK ŞOV İZMİR</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .navbar {
            background-color: #ff6b00 !important;
        }
        .btn-primary {
            background-color: #ff6b00;
            border-color: #ff6b00;
        }
        .btn-primary:hover {
            background-color: #e65d00;
            border-color: #e65d00;
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-dark navbar-expand-lg">
        <div class="container">
            <a class="navbar-brand" href="#">TAKTİK ŞOV İZMİR - Admin Panel</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" href="index.php">Başvurular</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="manual_application.php">Manuel Başvuru</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link active" href="sms_templates.php">SMS Şablonları</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="logout.php">Çıkış</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <div class="container mt-4">
        <div class="row justify-content-center">
            <div class="col-md-8">
                <?php if (isset($success)): ?>
                    <div class="alert alert-success"><?php echo $success; ?></div>
                <?php endif; ?>
                
                <?php if (isset($error)): ?>
                    <div class="alert alert-danger"><?php echo $error; ?></div>
                <?php endif; ?>

                <div class="card">
                    <div class="card-header">
                        <h4 class="mb-0">SMS Şablonları</h4>
                    </div>
                    <div class="card-body">
                        <div class="alert alert-info">
                            <strong>Kullanılabilir Değişkenler:</strong><br>
                            {AD_SOYAD} - Başvuru yapan kişinin adı soyadı<br>
                            {KOD} - SMS doğrulama kodu (sadece doğrulama SMS'inde kullanılır)
                        </div>

                        <?php while ($template = $templates->fetch_assoc()): ?>
                        <form method="POST" class="mb-4">
                            <input type="hidden" name="template_id" value="<?php echo $template['id']; ?>">
                            
                            <div class="mb-3">
                                <label class="form-label">
                                    <strong><?php echo ucfirst($template['template_name']); ?> SMS Şablonu:</strong>
                                </label>
                                <textarea class="form-control" name="content" rows="3" required><?php 
                                    echo htmlspecialchars($template['template_content']); 
                                ?></textarea>
                            </div>
                            
                            <button type="submit" class="btn btn-primary">Güncelle</button>
                        </form>
                        <?php endwhile; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
