-- Veritabanı oluşturma
CREATE DATABASE IF NOT EXISTS taktik_show_db CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
USE taktik_show_db;

-- Okullar tablosu
CREATE TABLE schools (
    id INT AUTO_INCREMENT PRIMARY KEY,
    school_name VARCHAR(255) NOT NULL,
    is_private BOOLEAN DEFAULT FALSE,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Başvurular tablosu
CREATE TABLE applications (
    id INT AUTO_INCREMENT PRIMARY KEY,
    full_name VARCHAR(255) NOT NULL,
    tc_no VARCHAR(11) NOT NULL,
    phone VARCHAR(15) NOT NULL,
    school_id INT NOT NULL,
    class_level ENUM('9', '10', '11', '12', 'Mezun', 'Ortaokul') NOT NULL,
    verification_code VARCHAR(6),
    is_verified BOOLEAN DEFAULT FALSE,
    is_manual BOOLEAN DEFAULT FALSE,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (school_id) REFERENCES schools(id),
    UNIQUE KEY unique_tc (tc_no),
    UNIQUE KEY unique_phone (phone)
);

-- SMS Şablonları tablosu
CREATE TABLE sms_templates (
    id INT AUTO_INCREMENT PRIMARY KEY,
    template_name VARCHAR(50) NOT NULL,
    template_content TEXT NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

-- Admin kullanıcıları tablosu
CREATE TABLE admin_users (
    id INT AUTO_INCREMENT PRIMARY KEY,
    username VARCHAR(50) NOT NULL UNIQUE,
    password VARCHAR(255) NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Örnek okul verileri
INSERT INTO schools (school_name, is_private) VALUES
('Özel Okul', 1),
('Bornova Anadolu Lisesi', 0),
('İzmir Fen Lisesi', 0),
('Karşıyaka Lisesi', 0),
('Atatürk Lisesi', 0);

-- Örnek SMS şablonları
INSERT INTO sms_templates (template_name, template_content) VALUES
('verification', 'Sayın {AD_SOYAD}, TAKTİK ŞOV İZMİR başvurunuz için doğrulama kodunuz: {KOD}'),
('success', 'Sayın {AD_SOYAD}, TAKTİK ŞOV İZMİR başvurunuz başarıyla alınmıştır.');

-- Örnek admin kullanıcısı (şifre: admin123)
INSERT INTO admin_users (username, password) VALUES
('admin', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi');
