<?php
require_once 'config.php';

$schools_query = $conn->query("SELECT * FROM schools ORDER BY school_name");
$schools = $schools_query->fetch_all(MYSQLI_ASSOC);
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>15 Mart TAKTİK ŞOV İZMİR - Başvuru Formu</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        :root {
            --orange: #ff6b00;
            --black: #000000;
        }
        body {
            background-color: #ffffff;
        }
        .navbar {
            background-color: var(--orange) !important;
        }
        .btn-primary {
            background-color: var(--orange);
            border-color: var(--orange);
        }
        .btn-primary:hover {
            background-color: #e65d00;
            border-color: #e65d00;
        }
        .form-container {
            max-width: 600px;
            margin: 2rem auto;
            padding: 2rem;
            border-radius: 10px;
            box-shadow: 0 0 20px rgba(0,0,0,0.1);
        }
        .header {
            color: var(--orange);
            text-align: center;
            margin-bottom: 2rem;
            font-weight: bold;
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-dark">
        <div class="container">
            <a class="navbar-brand" href="#">
                <img src="assets/img/logo.png" alt="TAKTİK ŞOV İZMİR" height="50">
            </a>
        </div>
    </nav>

    <div class="container">
        <div class="form-container">
            <div class="text-center mb-4">
                <img src="assets/img/logo.png" alt="TAKTİK ŞOV İZMİR" class="img-fluid" style="max-height: 120px;">
            </div>
            <h1 class="header">15 Mart TAKTİK ŞOV İZMİR</h1>
            <form id="applicationForm" method="POST" action="submit.php">
                <div class="mb-3">
                    <label for="fullName" class="form-label">Ad Soyad:</label>
                    <input type="text" class="form-control" id="fullName" name="fullName" required>
                </div>
                
                <div class="mb-3">
                    <label for="tcNo" class="form-label">TC Kimlik No:</label>
                    <input type="text" class="form-control" id="tcNo" name="tcNo" required 
                           pattern="[0-9]{11}" maxlength="11" minlength="11">
                </div>
                
                <div class="mb-3">
                    <label for="phone" class="form-label">Cep Telefonu:</label>
                    <input type="tel" class="form-control" id="phone" name="phone" required 
                           pattern="[0-9]{10}" maxlength="10" placeholder="5xxxxxxxxx">
                </div>
                
                <div class="mb-3">
                    <label for="school" class="form-label">Okul:</label>
                    <select class="form-select" id="school" name="school" required>
                        <option value="">Okul Seçiniz</option>
                        <?php foreach($schools as $school): ?>
                        <option value="<?php echo $school['id']; ?>">
                            <?php echo htmlspecialchars($school['school_name']); ?>
                        </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                
                <div class="mb-3">
                    <label for="classLevel" class="form-label">Sınıf:</label>
                    <select class="form-select" id="classLevel" name="classLevel" required>
                        <option value="">Sınıf Seçiniz</option>
                        <option value="9">9. Sınıf</option>
                        <option value="10">10. Sınıf</option>
                        <option value="11">11. Sınıf</option>
                        <option value="12">12. Sınıf</option>
                        <option value="Mezun">Mezun</option>
                        <option value="Ortaokul">Ortaokul</option>
                    </select>
                </div>
                
                <button type="submit" class="btn btn-primary w-100">Başvuru Yap</button>
            </form>
            
            <!-- SMS Doğrulama Modal -->
            <div class="modal fade" id="verificationModal" tabindex="-1">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title">SMS Doğrulama</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                        </div>
                        <div class="modal-body">
                            <p>Telefonunuza gönderilen doğrulama kodunu giriniz:</p>
                            <input type="text" class="form-control" id="verificationCode" maxlength="6">
                            <div id="timer" class="mt-2 text-center"></div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-primary" id="verifyCode">Doğrula</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        $(document).ready(function() {
            let timer;
            
            $('#applicationForm').on('submit', function(e) {
                e.preventDefault();
                $.ajax({
                    url: 'submit.php',
                    method: 'POST',
                    data: $(this).serialize(),
                    success: function(response) {
                        const data = JSON.parse(response);
                        if (data.status === 'success') {
                            $('#verificationModal').modal('show');
                            startTimer(120); // 2 dakika
                        } else {
                            alert(data.message);
                        }
                    }
                });
            });

            $('#verifyCode').click(function() {
                const code = $('#verificationCode').val();
                $.ajax({
                    url: 'verify.php',
                    method: 'POST',
                    data: {
                        code: code,
                        phone: $('#phone').val(),
                        tc: $('#tcNo').val()
                    },
                    success: function(response) {
                        const data = JSON.parse(response);
                        if (data.status === 'success') {
                            $('#verificationModal').modal('hide');
                            alert('Başvurunuz başarıyla alınmıştır!');
                            window.location.reload();
                        } else {
                            alert(data.message);
                        }
                    }
                });
            });

            function startTimer(duration) {
                let timer = duration;
                const timerDisplay = $('#timer');
                const countdown = setInterval(function() {
                    const minutes = parseInt(timer / 60, 10);
                    const seconds = parseInt(timer % 60, 10);
                    
                    timerDisplay.text(minutes + ":" + (seconds < 10 ? "0" : "") + seconds);
                    
                    if (--timer < 0) {
                        clearInterval(countdown);
                        $('#verificationModal').modal('hide');
                        alert('Süre doldu! Lütfen tekrar deneyiniz.');
                    }
                }, 1000);
            }
        });
    </script>
</body>
</html>
